==> open-cluster-management-apps-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmReleaseBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HelmReleaseBuilder extends io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseFluentImpl<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmRelease,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseBuilder>{
  public HelmReleaseBuilder() {
    this(false);
  }
  public HelmReleaseBuilder(java.lang.Boolean validationEnabled) {
    this(new HelmRelease(), validationEnabled);
  }
  public HelmReleaseBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmReleaseBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HelmRelease(), validationEnabled);
  }
  public HelmReleaseBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmRelease instance) {
    this(fluent, instance, false);
  }
  public HelmReleaseBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmRelease instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withRepo(instance.getRepo()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public HelmReleaseBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmRelease instance) {
    this(instance,false);
  }
  public HelmReleaseBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmRelease instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRepo(instance.getRepo()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmRelease build() {
    HelmRelease buildable = new HelmRelease(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getRepo(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmReleaseBuilder that = (HelmReleaseBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmReleaseBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HelmReleaseBuilder extends HelmReleaseFluentImpl<HelmReleaseBuilder> implements VisitableBuilder<HelmRelease,HelmReleaseBuilder>{
  public HelmReleaseBuilder() {
    this(false);
  }
  public HelmReleaseBuilder(Boolean validationEnabled) {
    this(new HelmRelease(), validationEnabled);
  }
  public HelmReleaseBuilder(HelmReleaseFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmReleaseBuilder(HelmReleaseFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HelmRelease(), validationEnabled);
  }
  public HelmReleaseBuilder(HelmReleaseFluent<?> fluent,HelmRelease instance) {
    this(fluent, instance, false);
  }
  public HelmReleaseBuilder(HelmReleaseFluent<?> fluent,HelmRelease instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withRepo(instance.getRepo()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public HelmReleaseBuilder(HelmRelease instance) {
    this(instance,false);
  }
  public HelmReleaseBuilder(HelmRelease instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRepo(instance.getRepo()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  HelmReleaseFluent<?> fluent;
  Boolean validationEnabled;
  public HelmRelease build() {
    HelmRelease buildable = new HelmRelease(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getRepo(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
